package com.jiuqi.mde;

import com.jiuqi.util.NumberFormatManager;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

/* loaded from: com_jiuqi_mde.jar:com/jiuqi/mde/MDEDimensionSet.class */
public class MDEDimensionSet implements Cloneable, Comparable {
    private String dimensionNames = null;
    private ArrayList dimensions = new ArrayList(2);
    private Map nameSearch = new HashMap(10);
    public static final int SCR_EQUAL = 0;
    public static final int SCR_MORE = 1;
    public static final int SCR_LESS = 2;
    public static final int SCR_LESS_AND_MORE = 3;

    public final int size() {
        return this.dimensions.size();
    }

    public final MDEDimension get(int index) {
        return (MDEDimension) this.dimensions.get(index);
    }

    public final MDEDimension find(String name) {
        Integer index = (Integer) this.nameSearch.get(name);
        if (index != null) {
            return (MDEDimension) this.dimensions.get(index.intValue());
        }
        return null;
    }

    public final void clear() {
        this.dimensions.clear();
        this.nameSearch.clear();
        this.dimensionNames = null;
    }

    private final int findOrder(String order) {
        int start = 0;
        int stop = this.dimensions.size() - 1;
        int flag = -1;
        while (start <= stop) {
            int middle = ((start + stop) + 1) >> 1;
            flag = order.compareTo(((MDEDimension) this.dimensions.get(middle)).order);
            if (flag > 0) {
                start = middle + 1;
            } else if (flag < 0) {
                stop = middle - 1;
            } else {
                start = middle;
                if (start == stop) {
                    break;
                }
            }
        }
        return flag == 0 ? start : (-start) - 1;
    }

    public final void add(MDEDimension dimension) {
        int index;
        if (!this.nameSearch.containsKey(dimension.name)) {
            int index2 = findOrder(dimension.order);
            if (index2 < 0) {
                index = (-1) - index2;
            } else {
                index = index2 + 1;
            }
            this.dimensionNames = null;
            this.dimensions.add(index, dimension);
            int count = this.dimensions.size();
            for (int i = index; i < count; i++) {
                this.nameSearch.put(((MDEDimension) this.dimensions.get(i)).name, NumberFormatManager.getInt(i));
            }
        }
    }

    public final void add(MDEDimensionSet dimensions) {
        int count = dimensions.size();
        for (int i = 0; i < count; i++) {
            add(dimensions.get(i));
        }
    }

    public final void remove(MDEDimension dimension) {
        Integer index = (Integer) this.nameSearch.get(dimension.name);
        if (index != null) {
            this.dimensionNames = null;
            this.nameSearch.remove(dimension.name);
            this.dimensions.remove(index.intValue());
            int count = this.dimensions.size();
            for (int i = index.intValue(); i < count; i++) {
                this.nameSearch.put(((MDEDimension) this.dimensions.get(i)).name, NumberFormatManager.getInt(i));
            }
        }
    }

    public final int indexOf(MDEDimension dimension) {
        Integer index = (Integer) this.nameSearch.get(dimension.name);
        if (index != null) {
            return index.intValue();
        }
        return -1;
    }

    public final int indexOf(String name) {
        Integer index = (Integer) this.nameSearch.get(name);
        if (index != null) {
            return index.intValue();
        }
        return -1;
    }

    public final boolean contains(MDEDimension dimension) {
        return this.nameSearch.get(dimension.name) != null;
    }

    public final boolean contains(String name) {
        return this.nameSearch.get(name) != null;
    }

    public final MDEDimension findByFieldName(String fieldName) {
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            MDEDimension dimension = (MDEDimension) this.dimensions.get(i);
            if (fieldName.equals(dimension.fieldName)) {
                return dimension;
            }
        }
        return null;
    }

    public final boolean hasOrder() {
        return find(MDEDimension.ORDER_NAME) != null;
    }

    public Object clone() {
        MDEDimensionSet result = new MDEDimensionSet();
        result.add(this);
        return result;
    }

    @Override // java.lang.Comparable
    public final int compareTo(Object o) {
        if (this == o) {
            return 0;
        }
        if (o == null) {
            return 1;
        }
        if (this == null) {
            return -1;
        }
        if (o instanceof MDEDimensionSet) {
            return toString().compareTo(((MDEDimensionSet) o).toString());
        }
        return hashCode() - o.hashCode();
    }

    public final boolean equals(Object o) {
        return compareTo(o) == 0;
    }

    public final int collectCompare(MDEDimensionSet another) {
        if (this == another) {
            return 0;
        }
        if (another == null) {
            return 1;
        }
        if (this == null) {
            return -1;
        }
        int result = 0;
        int matched = 0;
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            MDEDimension dimension = (MDEDimension) this.dimensions.get(i);
            if (another.contains(dimension)) {
                matched++;
            } else {
                result |= 1;
            }
        }
        if (matched < another.size()) {
            result |= 2;
        }
        return result;
    }

    public final boolean contains(MDEDimensionSet another) {
        int cr = collectCompare(another);
        return cr == 0 || cr == 1;
    }

    public boolean lessAndMore(MDEDimensionSet another) {
        int cr = collectCompare(another);
        return cr == 3;
    }

    public final String toString() {
        if (this.dimensionNames == null) {
            StringBuffer result = new StringBuffer(64);
            int count = this.dimensions.size();
            for (int i = 0; i < count; i++) {
                MDEDimension dimension = (MDEDimension) this.dimensions.get(i);
                if (0 != 0) {
                    result.append(", ");
                }
                result.append(dimension.name);
            }
            this.dimensionNames = result.toString();
        }
        return this.dimensionNames;
    }
}
